//+------------------------------------------------------------------+
//|                                           EGEN Trend Advisor.mq4 |
//|                             Copyright  2009, EGEN Software LTD. |
//|                                        http://www.metaquotes.net |
//+------------------------------------------------------------------+

#property copyright "Copyright  2009, EGEN Software LTD."
#property link      "http://www.metaquotes.net"

extern   bool     CloseAll          =  false;
extern   bool     Shutdown          =  false;
extern   double   TakeProfit        =  0;
extern   double   StopLoss          =  0;
extern   double   Lots              =  0.1;
extern   int      MaxOrders         =  100;
extern   int      Slippage          =  3;

datetime TIME; bool MOON;

bool EQ(int value1, int value2)
{
   return(value1==value2);
}

bool ZERO(int value)
{
   return(EQ(value,0));
}

datetime TIME()
{
   return(iTime(NULL,PERIOD_H1,0));
}

bool TOTAL(int index)
{
   return(index<OrdersTotal());
}

bool SYMBOL()
{
   return(EQ(OrderSymbol(),Symbol()));
}

bool SelectOrder(int index) 
{
   if(OrderSelect(index,SELECT_BY_POS)) 
      return(SYMBOL());
   return(false);         
}

bool CheckDay()
{
   datetime time1=TIME, time2=TIME();
   int day1=TimeDay(time1);
   int day2=TimeDay(time2);    
   if(ZERO(day2-day1)) return(false);        
   return(time2>time1);      
}

bool CheckHour()
{
   datetime time1=TIME, time2=TIME();
   bool flag1=(TimeHour(time1)<18);
   bool flag2=(TimeHour(time2)>17);    
   if(flag1) return(flag2);
   return(false);
}

bool CheckTime()
{
   if(CheckDay()) return(true); 
   return(CheckHour());
}

bool CheckMoon()
{  
   if(CheckTime()) 
      return(OrdersTotal()<MaxOrders); 
   return(false);      
}

void Buy()
{ 
   if(CheckMoon())
      OrderSend(Symbol(),OP_BUY,Lots,Ask,Slippage,0,0,NULL,0,0,Blue); 
   else return;      
   TIME=TIME(); 
}

void Sell()
{
   if(CheckMoon())
      OrderSend(Symbol(),OP_SELL,Lots,Bid,Slippage,0,0,NULL,0,0,Red);   
   else return;                              
   TIME=TIME();
}

int MOON()
{
   datetime T=TIME();    
   int Y=TimeYear(T);  
   int M=TimeMonth(T);   
   if(M<3) M+=12;   
   int D=TimeDay(T);
   int C=Y/100;
   int A=C/3+C/4+6-C;
   int S=MathRound((Y/19.0-MathFloor(Y/19.0))*209)+A+M+D;
   int F=MathRound((S/30.0-MathFloor(S/30.0))*30);  
   if(TimeHour(TimeLocal())<18) F--;
   if(F<0) F=29;    
   return(F);
}   

int DAY(int moon)
{
   int matrix[30]={-1,1,-1,1,-1,1,1,1,0,1,1,-1,-1,1,0,1,-1,1,-1,1,1,-1,1,0,-1,-1,1,1,-1,1};
   int day=matrix[moon];   
   return(day);
}

int PHASE(int moon)
{   
   if(moon>0)
      if(moon<16) return(1);
   return(-1);
}

int TREND()
{
   int moon=MOON(); return(PHASE(moon)*DAY(moon));
}

bool Shutdown()
{
   if(CheckTime())
      if(AccountProfit()>0) Shutdown=true;
   return(Shutdown);      
}
   
void SendOrder() 
{
   if(Shutdown()) return;
   if(TREND()<0) 
      Sell(); else 
   if(TREND()>0) 
      Buy();
   else return;            
}              

int ORDER()
{   
   if(EQ(OrderType(),OP_SELL))       
      return(-1); 
   if(EQ(OrderType(),OP_BUY)) 
      return(1); 
   return(0);      
}  

double PRICE()
{
   if(ORDER()>0) return(Bid);
      else 
   if(ORDER()<0) return(Ask);     
}

void CloseTicket()
{
   OrderClose(OrderTicket(),OrderLots(),PRICE(),Slippage,White); 
}

void CloseOrder(int index)
{  
   if(SelectOrder(index)) CloseTicket();
}

void CloseAll()
{
   if(OrdersTotal()>0)
      for(int i=0; TOTAL(i); i++) CloseOrder(i);
   else Shutdown=false;      
}

bool TakeProfit()
{
   if(TakeProfit>0)
      return(AccountEquity()>TakeProfit); 
   return(false);      
}

bool StopLoss()
{
   if(StopLoss>0)
      return(AccountEquity()<StopLoss);
   return(false);      
}

void CheckTrade()
{
   if(CloseAll) 
      CloseAll(); else
   if(Shutdown)
      CloseAll(); else      
   if(TakeProfit()) 
      CloseAll=true; else
   if(StopLoss()) 
      CloseAll=true; else 
   SendOrder();  
}
  
void start()
{
   if(IsTradeAllowed()) CheckTrade();
}


